import {
    processSendQueue,
    initializeSendQueue,
    fetchGeneratedMessages,
    showMessagesModal,
    updateAllActions,
    renderTags,
    populateContactsTable,
    initializeTabControls,
    initializeAutoCloseToggle,
    delay,
    updateTabCount,
    generateMessages,
    loadSendListFromStorage
} from './index.js';

import { initializeStats } from './modules/statsManager.js';

document.addEventListener('DOMContentLoaded', async () => {
    console.log('Contact Automator page loaded - Starting initialization');
    
    await initializeAutoCloseToggle();
    initializeTabControls();
    initializeSendQueue();
    
    // Initialize stats first
    await initializeStats();
    
    // Load messages from Chrome storage
    await loadSendListFromStorage();
    
    // Get the stored contact URLs
    const storedUrls = localStorage.getItem('selectedContactsUrls');
    console.log('Retrieved URLs from localStorage:', storedUrls);

    try {
        const urls = JSON.parse(storedUrls) || [];
        console.log('Parsed URLs:', urls);
        
        // Update the tab count display
        updateTabCount('tabContactCount', urls.length);

        // Get authentication details
        const { email, authentication_token } = await chrome.storage.local.get(['email', 'authentication_token']);
        
        if (!email || !authentication_token) {
            throw new Error('Authentication credentials not found');
        }

        // Populate the contacts table
        await populateContactsTable(urls, email, authentication_token);

        // Initialize event listeners
        document.getElementById('skipAllButton')?.addEventListener('click', () => {
            console.log('Skip All button clicked');
            updateAllActions('skip');
        });

        document.getElementById('visitAllButton')?.addEventListener('click', () => {
            console.log('Visit All button clicked');
            updateAllActions('visit_profile');
        });

        document.getElementById('promoAllButton')?.addEventListener('click', () => {
            console.log('Promo All button clicked');
            updateAllActions('promo_message');
        });

        // Add event delegation for messages count buttons
        document.querySelector('#selectedContactsTable')?.addEventListener('click', (e) => {
            if (e.target.classList.contains('messages-count-button')) {
                try {
                    const encodedMessages = e.target.dataset.messages;
                    const messages = JSON.parse(decodeURIComponent(encodedMessages));
                    showMessagesModal(messages);
                } catch (error) {
                    console.error('Error parsing messages:', error);
                    alert('Error loading messages. Please try again.');
                }
            }
        });

        // Add event listener for Generate Messages button
        document.getElementById('generateMessagesButton')?.addEventListener('click', async () => {
            console.log('Generate Messages button clicked');
            const { email, authentication_token } = await chrome.storage.local.get(['email', 'authentication_token']);
            generateMessages(email, authentication_token);
        });

    } catch (error) {
        console.error('Error loading contacts:', error);
        document.querySelector('.container').innerHTML += `
            <div class="error-message">Error loading contacts: ${error.message}</div>
        `;
    }
}); 