// Script to check recent LinkedIn connections
const API_BASE_URL = 'https://www.goai-app.com';
const CONNECTIONS_PAGE_URL = 'linkedin.com/mynetwork/invite-connect/connections/';

async function updateContact(contactId) {
    try {
        const { email, authentication_token: authToken } = await chrome.storage.local.get(['email', 'authentication_token']);
        
        const response = await fetch(`${API_BASE_URL}/updateContact`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json'
            },
            body: JSON.stringify({
                email,
                authToken,
                contactId
            })
        });

        if (!response.ok) {
            throw new Error(`Failed to update contact: ${response.statusText}`);
        }

        return await response.json();
    } catch (error) {
        console.error('Error updating contact:', error);
        throw error;
    }
}

export function checkRecentConnections() {
    // First check if we're on the connections page
    if (!window.location.href.includes(CONNECTIONS_PAGE_URL)) {
        console.log('Not on connections page, skipping check');
        return;
    }

    console.log('On connections page, starting check');
    
    // Wait for the main element to be present in the DOM
    const waitForMain = setInterval(() => {
        const mainElement = document.querySelector('main');
        if (mainElement) {
            clearInterval(waitForMain);
            scanForConnectionLinks(mainElement);
        }
    }, 1000); // Check every second
}

function scanForConnectionLinks(mainElement) {
    // Use a Set to track unique contact IDs
    const processedContactIds = new Set();
    
    // Find all <a> elements that match the pattern /in/*/
    const connectionLinks = mainElement.querySelectorAll('a[href^="/in/"]');
    console.log(`Found ${connectionLinks.length} potential connection links`);
    
    connectionLinks.forEach(async link => {
        // Check if the href matches the pattern /in/*/
        const href = link.getAttribute('href');
        if (href.match(/^\/in\/[^\/]+\/?$/)) {
            // Extract the contact ID from the href
            const contactId = href.split('/in/')[1].replace(/\/$/, '');
            
            // Skip if we've already processed this contact ID
            if (processedContactIds.has(contactId)) {
                return;
            }
            
            // Add to processed set
            processedContactIds.add(contactId);
            
            console.log(`Processing contact: ${contactId}`);
            
            try {
                // Call the updateContact endpoint
                const result = await updateContact(contactId);
                console.log(`Updated contact ${contactId}:`, result);
            } catch (error) {
                console.error(`Failed to update contact ${contactId}:`, error);
            }
        }
    });
    
    console.log(`Total unique contacts found: ${processedContactIds.size}`);
}

// Run the script when the page is loaded
if (document.readyState === 'complete') {
    checkRecentConnections();
} else {
    window.addEventListener('load', checkRecentConnections);
}
