// Track URL changes and handle URL-related functionality
export function setupUrlHandlers(resetUIState) {
    observeUrlChange();
    setupUrlChangeListener(resetUIState);
}

// Observe for URL changes (single-page navigation)
function observeUrlChange() {
    let lastUrl = location.href;
    new MutationObserver(() => {
        const currentUrl = location.href;
        if (currentUrl !== lastUrl) {
            lastUrl = currentUrl;
        }
    }).observe(document, { subtree: true, childList: true });
}

// Setup URL change listener for LinkedIn
function setupUrlChangeListener(resetUIState) {
    let lastUrl = window.location.href;
    
    const observer = new MutationObserver(() => {
        if (lastUrl !== window.location.href) {
            handleUrlChange(lastUrl, window.location.href, resetUIState);
            lastUrl = window.location.href;
        }
    });

    observer.observe(document.body, {
        childList: true,
        subtree: true
    });
}

// Handle URL changes
function handleUrlChange(fromUrl, toUrl, resetUIState) {
    chrome.runtime.sendMessage({
        action: 'URL_CHANGED',
        from: fromUrl,
        to: toUrl
    });
    
    chrome.runtime.sendMessage({
        action: 'sendAnalyticsEvent',
        eventName: 'linkedin_page_url_changed',
        eventParams: {
            from: fromUrl,
            to: toUrl
        }
    });

    resetUIState();
}