const API_BASE_URL = 'https://www.goai-app.com';

document.addEventListener('DOMContentLoaded', async function() {
    // Send analytics event
    chrome.runtime.sendMessage({
        action: 'sendAnalyticsEvent',
        eventName: 'post_creator_page_loaded',
        eventParams: {}
    });

    try {
        // Load About You and About Product content from API
        const { email, authentication_token } = await chrome.storage.local.get(['email', 'authentication_token']);
        
        if (!email || !authentication_token) {
            console.error('Missing email or authentication token');
            throw new Error('Please log in again to access your settings');
        }

        // Get About You and About Product from API
        const aboutFilesResponse = await fetch(
            `${API_BASE_URL}/getAboutFiles?email=${encodeURIComponent(email)}&authToken=${authentication_token}`,
            {
                headers: {
                    'Accept': 'application/json'
                }
            }
        );

        if (!aboutFilesResponse.ok) {
            throw new Error(`HTTP error! status: ${aboutFilesResponse.status}`);
        }

        const aboutData = await aboutFilesResponse.json();
        if (aboutData.success) {
            document.getElementById('aboutYou').value = aboutData.aboutYou || '';
            document.getElementById('aboutProduct').value = aboutData.aboutProduct || '';
        } else {
            throw new Error(aboutData.message || 'Failed to load about files from server');
        }

        // Disable and set tooltips for read-only text areas
        const aboutYouTextarea = document.getElementById('aboutYou');
        const aboutProductTextarea = document.getElementById('aboutProduct');

        // Set disabled state and tooltip
        aboutYouTextarea.disabled = true;
        aboutProductTextarea.disabled = true;
        aboutYouTextarea.title = "To edit, go to Settings";
        aboutProductTextarea.title = "To edit, go to Settings";

        // Add event listener for generate button
        document.getElementById('generateButton').addEventListener('click', async () => {
            const generateButton = document.getElementById('generateButton');
            const testingInfo = document.querySelector('.testing-information');
            
            // Disable button while generating
            generateButton.disabled = true;
            generateButton.textContent = 'Generating...';
            
            try {
                const { email, authentication_token } = await chrome.storage.local.get(['email', 'authentication_token']);
                
                const payload = {
                    email,
                    authToken: authentication_token,
                    instructions: document.getElementById('postInstructions').value
                };

                const response = await fetch(`${API_BASE_URL}/generatePost`, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'Accept': 'application/json'
                    },
                    body: JSON.stringify(payload)
                });

                const data = await response.json();

                if (data.success) {
                    // Show the generated content section
                    document.getElementById('generatedContent').classList.remove('hidden');
                    document.getElementById('generatedPost').innerText = data.post;
                    // Show the image generation section
                    document.getElementById('imageGeneration').classList.remove('hidden');
                } else {
                    testingInfo.textContent = `Error: ${data.error}`;
                }
            } catch (error) {
                testingInfo.textContent = `Error: ${error.message}`;
            } finally {
                // Re-enable button
                generateButton.disabled = false;
                generateButton.textContent = 'Generate Post!';
            }
        });

        // Add event listener for generate image button
        document.getElementById('generateImageButton').addEventListener('click', async () => {
            const generateImageButton = document.getElementById('generateImageButton');
            const generatedPost = document.getElementById('generatedPost').textContent;
            
            if (!generatedPost) {
                alert('Please generate a post first!');
                return;
            }

            // Disable button while generating
            generateImageButton.disabled = true;
            generateImageButton.textContent = 'Generating Image...';
            
            try {
                const response = await chrome.runtime.sendMessage({
                    type: 'GENERATE_POST_IMAGE',
                    data: { postContent: generatedPost }
                });

                if (response.success) {
                    const imageContainer = document.getElementById('generatedImage');
                    imageContainer.innerHTML = `<img src="${response.imageUrl}" alt="Generated post image">`;
                } else {
                    alert(`Error: ${response.error}`);
                }
            } catch (error) {
                alert(`Error: ${error.message}`);
            } finally {
                // Re-enable button
                generateImageButton.disabled = false;
                generateImageButton.textContent = 'Generate Image';
            }
        });

    } catch (error) {
        console.error('Error initializing post generator:', error);
    }
}); 