const API_BASE_URL = 'https://www.goai-app.com';

const apiUtils = {
    async getAuthCredentials() {
        return new Promise((resolve, reject) => {
            chrome.storage.local.get(['email', 'authentication_token'], (result) => {
                if (chrome.runtime.lastError) {
                    return reject(chrome.runtime.lastError);
                }
                resolve({
                    email: result.email,
                    authToken: result.authentication_token
                });
            });
        });
    },

    async findContact(profileUrl) {
        try {
            const { email, authToken } = await this.getAuthCredentials();
            const response = await fetch(`${API_BASE_URL}/findContact`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'Accept': 'application/json'
                },
                body: JSON.stringify({ email, authToken, profileUrl })
            });

            if (!response.ok) {
                throw new Error(`API request failed: ${response.statusText}`);
            }

            return await response.json();
        } catch (error) {
            console.error('Error finding contact:', error);
            throw error;
        }
    },

    async saveContact(contact) {
        try {
            const { email, authToken } = await this.getAuthCredentials();
            const response = await fetch(`${API_BASE_URL}/addContact`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'Accept': 'application/json'
                },
                body: JSON.stringify({ email, authToken, contact })
            });

            if (!response.ok) {
                throw new Error(`API request failed: ${response.statusText}`);
            }

            return await response.json();
        } catch (error) {
            console.error('Error saving contact:', error);
            throw error;
        }
    },

    async updateContactTags(profileUrl, tags) {
        try {
            const { email, authToken } = await this.getAuthCredentials();
            const response = await fetch(`${API_BASE_URL}/updateContactTags`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'Accept': 'application/json'
                },
                body: JSON.stringify({ email, authToken, profileUrl, tags })
            });

            if (!response.ok) {
                throw new Error(`API request failed: ${response.statusText}`);
            }

            return await response.json();
        } catch (error) {
            console.error('Error updating contact tags:', error);
            throw error;
        }
    },

    async getAllContacts() {
        try {
            const { email, authToken } = await this.getAuthCredentials();
            const response = await fetch(`${API_BASE_URL}/getContacts`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'Accept': 'application/json'
                },
                body: JSON.stringify({ email, authToken })
            });

            if (!response.ok) {
                throw new Error(`API request failed: ${response.statusText}`);
            }

            return await response.json();
        } catch (error) {
            console.error('Error getting contacts:', error);
            throw error;
        }
    }
};

// Make apiUtils available globally
window.apiUtils = apiUtils;

export default apiUtils; 