import apiUtils from './apiUtils.js';

async function analyzeProfileData(url) {
    try {
        const result = await apiUtils.findContact(url);
        return {
            exists: !!result.contact,
            profileData: result.contact
        };
    } catch (error) {
        console.error('Error analyzing profile data:', error);
        return { exists: false };
    }
}

async function findAndProcessContact(profileUrl, profileData) {
    try {
        console.group('Processing Contact');
        console.log('Profile URL:', profileUrl);
        console.log('Profile Data:', profileData);

        // Create contact object
        const contact = {
            ContactProfileURL: profileUrl,
            RefreshDatetime: new Date().toISOString(),
            ContactFirstname: profileData.ContactFirstname || '',
            ContactLastname: profileData.ContactLastname || '',
            ContactJobTitle: profileData.ContactJobTitle || '',
            ContactCurrentCompany: profileData.ContactCurrentCompany || '',
            ContactTags: profileData.ContactTags || [],
            existingContact: profileData.existingContact || false,
            ...profileData
        };

        // Save contact through API
        const result = await apiUtils.saveContact(contact);
        
        console.log('Contact processed successfully');
        console.groupEnd();
        
        return {
            success: true,
            contact: result.contact
        };
    } catch (error) {
        console.error('Error in findAndProcessContact:', error);
        console.groupEnd();
        throw error;
    }
}

export {
    analyzeProfileData,
    findAndProcessContact
}; 